arabic_male = [
    "Mohamed",
    "Mahmoud",
    "Mustafa",
    "Yassin",
    "Taha",
    "Khaled",
    "Hamza",
    "Bilal",
    "Ibrahim",
    "Hassan",
    "Hussein",
    "Karim",
    "Tareq",
    "Abdel-Rahman",
    "Ali",
    "Omar",
    "Halim",
    "Murad",
    "Selim",
    "Abdallah",
    "Fadi",
    "Habib",
    "Ahmed",
    "Ali",
    "Yousouf",
    "Omar",
    "Adam",
    "Abd",
    "Khaled",
    "Fahd"
]

arabic_female = [
    "Shaimaa",
    "Fatma",
    "Maha",
    "Reem",
    "Farida",
    "Aya",
    "Shahd",
    "Ashraqat",
    "Sahar",
    "Fatin",
    "Doha",
    "Fajr",
    "Suha",
    "Rowan",
    "Hosniya",
    "Hasnaa",
    "Hosna",
    "Gamila",
    "Gamalat",
    "Habiba",
    "Mariam",
    "Malak",
    "Habiba",
    "Hana",
    "Farah",
    "Marwa",
    "Nada",
    "Salma"
]

arabic_surnames = [
    "Ansari",
    "Khan",
    "Mirza",
    "Sayyed",
    "Shah",
    "Shaikh",
    "Sheikh",
]

english_surnames = [
    "Smith",
    "Jones",
    "Taylor",
    "Brown",
    "Williams",
    "Wilson",
    "Johnson",
    "Davies",
    "Robinson",
    "Wright",
    "Thompson",
    "Evans",
    "Walker",
    "White",
    "Roberts",
    "Green",
    "Hall",
    "Wood",
    "Jackson",
    "Clark"
]

english_male = [
    "Peter",
    "Pierre",
    "George",
    "John",
    "Mina",
    "Beshoi",
    "Kirollos",
    "Mark",
    "Noah",
    "William",
    "Thomas",
    "Leo",
    "Liam",
    "Jacob",
    "Nathan",
    "Arthur",
    "Felix",
    "Oliver",
    "Elijah",
    "James",
    "Benjamin",
    "Lucas",
    "Henry",
    "Theodore",
    "Robert",
    "Micheal",
    "David", 
    "Richard", 
    "Charles", 
    "Joseph", 
    "Steve",
    "Mateo",
    "Bautista",
    "Juan",
    "Felipe",
    "Bruno",
    "Noah",
    "Benicio",
    "Thiago",
    "Ciro",
    "Liam"
]

english_female = [
    "Mary",
    "Patricia",
    "Linda",
    "Barbara",
    "Elizabeth",
    "Jennifer",
    "Maria",
    "Susan",
    "Margaret",
    "Dorothy",
    "Olivia",
    "Emma",
    "Charlotte",
    "Amelia",
    "Ava",
    "Sophia",
    "Isabella",
    "Mia",
    "Evelyn",
    "Harper",
    "Irene",
]