qualifications = [
        "High school",
        "Diploma in Fire safety",
        "Diploma in Health safety",
        "Diploma in Pharmacy",
        "Bachelor of Arts (B.A)", 
        "Bachelor of Fine Arts (B.F.A)",
        "Bachelor of Business Administration (B.B.A.)",
        "Integrated Law course (B.A + L.L.B.)",
        "Bachelor of Journalism and Mass Communication (B.J.M.)",
        "Bachelor of Fashion Design (B.F.D.)"
        "Bachelor of Science", 
        "Bachelor of Science (Artificial Intelligence)", 
        "Bachelor of Science (Information Technology)", 
        "Bachelor of Science (Computer Science)", 
        "Bachelor of Science (Data Science)", 
        "Bachelor of Commerce (B.Com)",
        "Bachelor of Management Studies (B.Ms))",
        "Bachelor of Enginnering (Civil)",
        "Bachelor of Enginnering (Electronics)",
        "Bachelor of Enginnering (Electronic & Telecommunications)",
        "Bachelor of Enginnering (Mechanical)",
        "Bachelor of Enginnering (Computer)",
        "Bachelor of Enginnering (Chemical engineering)",
        "Bachelor of Enginnering (Nuclear engineering)",
        "Bachelor of Pharmacy (B.Pharm)",
        "Bachelor of Unani Medicine (BUMS)",
        "Bachelor of Ayurvedic Medicine (BAMS)",
        "Bachelor of Medicine, Bachelor of Surgery (MBBS)",
        "Doctor of Medicine (MD)",
        "Master of Arts",
        "Master of Science",
        "Master of Science (Artificial Intelligence)", 
        "Master of Science (Information Technology)", 
        "Master of Science (Computer Science)",
        "Master of Science (Cloud Computing)",
        "Master of Science (Data Science)",
        "Master of bussiness administration (MBA)",
        "Master of managemnt studies (MMS)",
        "Master of Enginnering (Civil)",
        "Master of Enginnering (Electronics)",
        "Master of Enginnering (Electronic & Telecommunications)",
        "Master of Enginnering (Mechanical)",
        "Master of Enginnering (Computer)",
        "Master of Enginnering (Chemical engineering)",
        "Master of Enginnering (Nuclear engineering)",
        "NEEBOSH",
        "Phd",
    ]